@@ -1,12 +1,17 @@
 #!/usr/bin/env python
 # Copyright 2020 Grid AI Inc.
 """Entrypoint for the Grid CLI."""
+import sys
+
 import click
+from click import ClickException
 
 import grid.cli as cli
 import grid.globals as env
-
-from grid.metadata import __version__, __logo__
+from grid.metadata import __logo__
+from grid.metadata import __version__
+from grid.tracking import Segment
+from grid.tracking import TrackingEvents
 from grid.utilities import introspect_module
 
 
@@ -42,7 +47,22 @@ def version() -> None:
 #  Adds all CLI commands. Commands are introspected
 #  from the cli module.
 for command in introspect_module(cli):
+    command: click.Command
+    main: click.Group
     main.add_command(command)
 
 if __name__ == '__main__':
-    main()
+    tracker = Segment()
+    tracker.send_event(event=TrackingEvents.CLI_STARTED)
+    try:
+        main.main(prog_name="grid", standalone_mode=False)
+        tracker.send_event(event=TrackingEvents.CLI_FINISHED)
+    except ClickException as e:
+        tracker.report_exception(e)
+        e.show()
+        sys.exit(e.exit_code)
+    except Exception as e:
+        tracker.report_exception(e)
+        sys.exit(1)
+    finally:
+        tracker.flush()
