@@ -3,10 +3,11 @@ from typing import Optional
 import click
 
 from grid import Grid
+from grid.utilities import check_is_experiment
 
 
 @click.command()
-@click.argument('experiment', type=str, nargs=1)
+@click.argument('experiment', type=str, nargs=1, callback=check_is_experiment)
 @click.option('--n_lines',
               default=10,
               type=int,
