@@ -989,8 +989,7 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
 
         elif not success:
             spinner.fail("✘")
-            if env.DEBUG:
-                click.echo(f"→ {result['createInteractiveNode']['message']}")
+            click.echo(f"→ {result['createInteractiveNode']['message']}")
 
             raise click.ClickException(
                 f"Failed to create interactive node '{name}'")
@@ -1824,14 +1823,14 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
             raise click.ClickException(f"Unable to list datastores: {e}")
 
         table_cols = [
-            "Credential Id", 'Name', 'Version', 'Size', 'Created', 'Status'
+            "Credential Id", "Name", "Version", "Size", "Created", "Status"
         ]
         table = BaseObservable.create_table(columns=table_cols)
         for row in result["getDatastores"]:
             created_at = date_string_parse(row["createdAt"])
             created_at = f'{created_at:%Y-%m-%d %H:%M}'
             size = row["size"]
-            if size:
+            if size or size == 0:
                 size = humanize.naturalsize(size * (1024**2))
 
             if row['snapshotStatus'] in {
@@ -1841,6 +1840,7 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
             else:
                 status = row['snapshotStatus'].title(
                 ) if row['snapshotStatus'] else "Unknown"
+
             table.add_row(row["credentialId"], row["name"], row["version"],
                           size, created_at, status)
 
