@@ -2,8 +2,10 @@
 from datetime import datetime
 from datetime import timedelta
 from datetime import timezone
+import importlib.resources as pkg_resources
 import os
 from os import listdir
+from pathlib import Path
 import re
 from shlex import split
 from types import ModuleType
@@ -16,6 +18,8 @@ from google.cloud import storage
 import pytz
 from tzlocal import get_localzone
 
+from grid import autocomplete
+
 
 class GCPStorage:  # pragma: no cover
     """
@@ -332,3 +336,63 @@ def check_run_name_is_valid(_ctx, _param, value):
                 """)
 
     return value
+
+
+def check_description_isnt_too_long(ctx, _param, value):
+    """Click callback that checks if the description isn't too long."""
+    if value is not None and len(value) > 200:
+        raise click.BadParameter('Description should have at most '
+                                 f'200 characters. Yous has {len(value)}.')
+    return value
+
+
+def install_autocomplete() -> None:
+    """
+    Installs autocomplete files from package resources, and activates in users shell config.
+    """
+    home = Path.home()
+    # this should probably be a global but no one seems to be doing that
+    # for .grid files
+    complete = home / ".grid/autocomplete"
+
+    bashrc = home / ".bashrc"
+    zshrc = home / ".zshrc"
+    bash_complete = complete / "complete.bash"
+    zsh_complete = complete / "complete.zsh"
+
+    complete.mkdir(parents=True, exist_ok=True)
+
+    bash_complete.write_text(
+        pkg_resources.read_text(autocomplete, "complete.bash"))
+    zsh_complete.write_text(
+        pkg_resources.read_text(autocomplete, "complete.zsh"))
+
+    for rc, sh_complete in zip([bashrc, zshrc], [bash_complete, zsh_complete]):
+        # Adds necessary activation to shell config if the file exists and doesn't already contain
+        if rc.exists() and str(sh_complete) not in rc.read_text():
+            with rc.open("a") as f:
+                f.write(
+                    "\n# Grid Autocomplete\n"
+                    f"if [ -f '{sh_complete}' ]; then . '{sh_complete}' ; fi\n"
+                )
+
+
+def check_is_experiment(_ctx, _param, value):
+    """
+    Click callback that checks if passed list of experiments are
+    actual experiments.
+    """
+    if isinstance(value, str):
+        if not is_experiment(value):
+            raise click.BadArgumentUsage(
+                f"{value} is not an experiment. "
+                "You can only download artifacts for experiments.")
+
+    else:
+        for experiment in value:
+            if not is_experiment(experiment):
+                raise click.BadArgumentUsage(
+                    f"{experiment} is not an experiment. "
+                    "You can only download artifacts for experiments.")
+
+    return value
