@@ -367,10 +367,33 @@ def test_train(monkeypatch):
                         monkey_patch_token_check)
 
     env.DEBUG = True
+    description = 199 * '-'  # 200 characters is the limit.
     result = RUNNER.invoke(cli.train, [
-        '--grid_credential', CREDENTIAL_ID, '--grid_strategy', 'grid_search',
-        '--grid_trials', "1", '--ignore_warnings', 'tests/data/script.py'
+        '--grid_credential', CREDENTIAL_ID, '--grid_description', description,
+        '--grid_strategy', 'grid_search', '--grid_trials', "1",
+        '--ignore_warnings', 'tests/data/script.py'
+    ])
+    assert result.exit_code == 0
+    assert not result.exception
+
+
+def test_train_with_framework(monkeypatch):
+    """grid train takes a famework parameters"""
+    monkeypatch.setattr(grid, 'gql', lambda x: x)
+    monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
+
+    monkeypatch.setattr(grid.Grid, 'get_credentials',
+                        monkey_patch_get_credentials)
+    monkeypatch.setattr(grid.Grid, '_set_local_credentials', lambda x: True)
+    monkeypatch.setattr(grid.Grid, '_check_user_github_token',
+                        monkey_patch_token_check)
+
+    env.DEBUG = True
+    result = RUNNER.invoke(cli.train, [
+        '--grid_credential', CREDENTIAL_ID, '--grid_description', 'test',
+        '--grid_strategy', 'grid_search', '--grid_trials', "1",
+        '--grid_framework', 'lightning', '--ignore_warnings',
+        'tests/data/script.py'
     ])
-
     assert result.exit_code == 0
     assert not result.exception
