@@ -1,17 +1,19 @@
 import click
-import unittest
-
+import pytest
 from tests.utilities import captured_output
+
 from grid.cli.grid_credentials import print_creds_table
 
 
-class CredentialsUtilitiesTestCase(unittest.TestCase):
+class TestCredentialsUtilities:
     """Test utilities in credentials."""
-    def test_print_creds_table_raises_exception(self):
-        with self.assertRaises(click.ClickException):
+    @staticmethod
+    def test_print_creds_table_raises_exception():
+        with pytest.raises(click.ClickException):
             print_creds_table(creds=[])
 
-    def test_print_creds_table_prints_table(self):
+    @staticmethod
+    def test_print_creds_table_prints_table():
         credentials = [{
             'credentialId': 'test',
             'provider': 'test',
