@@ -1,10 +1,10 @@
-import os
-import grid.globals as env
-from grid.client import Grid
-
 from pathlib import Path
+
 from tests.utilities import create_local_schema_client
 
+from grid.client import env
+from grid.client import Grid
+
 SETTINGS_PATH = 'tests/data/settings.json'
 CREDENTIALS_PATH = 'tests/data/credentials.json'
 
@@ -13,13 +13,10 @@ def monkey_patch_client(self):
     self.client = create_local_schema_client()
 
 
-#  skipcq: PYL-W0212
-Grid._init_client = monkey_patch_client
-
-
-def test_load_global_settings():
+def test_load_global_settings(monkeypatch):
     """Grid() loads global settings alters globals."""
 
+    monkeypatch.setattr(Grid, '_init_client', monkey_patch_client)
     Grid.grid_settings_path = SETTINGS_PATH
     Grid(credential_path=CREDENTIALS_PATH, load_local_credentials=False)
 
