@@ -2,6 +2,7 @@ from datetime import datetime
 from datetime import timedelta
 from datetime import timezone
 import os
+from pathlib import Path
 import random
 import unittest
 
@@ -9,6 +10,7 @@ import click
 from dateutil.parser import parse as date_string_parse
 import pytest
 
+from grid.utilities import check_description_isnt_too_long
 from grid.utilities import check_environment_variables
 from grid.utilities import check_is_python_script
 from grid.utilities import check_run_name_is_valid
@@ -17,6 +19,7 @@ from grid.utilities import get_abs_time_difference
 from grid.utilities import get_experiment_duration_string
 from grid.utilities import get_graphql_url
 from grid.utilities import get_param_values
+from grid.utilities import install_autocomplete
 from grid.utilities import introspect_module
 from grid.utilities import is_experiment
 from grid.utilities import string_format_timedelta
@@ -58,6 +61,36 @@ def test_check_run_name_raises_exception_if_experiment():
         check_run_name_is_valid(None, None, experiment_name)
 
 
+def test_check_description_isnt_too_long():
+    """
+    _check_description_isnt_too_long() checks that description isn't
+    too long
+    """
+    d = 'a' * 199
+    assert d == check_description_isnt_too_long(None, None, d)
+
+    d = 'a' * 201
+    with pytest.raises(click.BadParameter):
+        check_description_isnt_too_long(None, None, d)
+
+
+def test_install_autocomplete(mocker, tmpdir):
+    mocker.patch("pathlib.Path.home", return_value=Path(tmpdir))
+    home = Path.home()
+    (home / ".bashrc").write_text("")
+    (home / ".zshrc").write_text("")
+    install_autocomplete()
+    assert (Path.home() / ".grid/autocomplete/complete.zsh").exists()
+    assert (Path.home() / ".grid/autocomplete/complete.bash").exists()
+    assert (home / ".bashrc").read_text().count("grid") == 2
+    assert (home / ".zshrc").read_text().count("grid") == 2
+
+    # make sure we are not writing more than once
+    install_autocomplete()
+    assert (home / ".bashrc").read_text().count("grid") == 2
+    assert (home / ".zshrc").read_text().count("grid") == 2
+
+
 class UtilitiesTestCase(unittest.TestCase):
     """Test utilities in credentials."""
     def test_convert_utc_string_to_local_datetime(self):
